@@ -4,12 +4,12 @@ var path = require('path');
 var createService = function(self, provider) {
   var file = self.readFileAsString(path.join(__dirname, '../templates/scripts/' + provider + 'AuthService.js'))
   file = file.replace(new RegExp("{{APP_NAME}}", 'g'), self.appName);  
-  var filePath = path.join(self.appPath, provider+'Service.js');
+  var filePath = path.join(self.servicePath, provider+'Service.js');
   self.write(filePath, file);
   self.scriptsFile.push(filePath);
 }
 
-var prompt: [{
+var prompt = [{
     type: 'checkbox',
     name: 'providers',
     message: 'Which Authentification provider would you like to include?',
@@ -41,11 +41,18 @@ module.exports = {
   },
   install: function(self) {
     var choices = self.auth;
-    var done = self.async();
-    for (var i = choices.length - 1; i >= 0; i--) {
-      console.log('Choice:' + choices[i]);
-      createService(self, choices[i]);
-    };
-    done();
+    if (choices) {
+      var done = self.async();
+      for (var i = choices.length - 1; i >= 0; i--) {
+        console.log('Choice:' + choices[i]);
+        createService(self, choices[i]);
+      };
+      var file = self.readFileAsString(path.join(__dirname, '../templates/scripts/AuthService.js'))
+      file = file.replace(new RegExp("{{APP_NAME}}", 'g'), self.appName);  
+      var filePath = path.join(self.servicePath, 'AuthService.js');
+      self.write(filePath, file);
+      self.scriptsFile.push(filePath);
+      done();      
+    }
   }
 };
