@@ -7,6 +7,8 @@ module.exports = {
   starters: require('./starters'),
   auth: require('./auth.js'),
   routes: require('./routes.js'),
+  push: require('./push.js'),
+  analytics: require('./analytics.js'),
   models: require('./models.js')
 };
 
