@@ -52,16 +52,16 @@ var showRouteStatePrompt = function(self, done) {
   });
 }
 
-var generateConfigRoute = function(self, configRoutes, route) {
+var generateConfigRoute = function(self, route) {
   var ctrl = camelCase(route.state) + 'Ctrl';
   var view = camelCase(route.state);
-  configRoutes += 
-    ".state(\'"+ route.state +"\', {\n" +
-    "url: \'" + route.url + "',\n" +
-    "templateUrl: \'templates/" + view + "\'\n,"+
-    "controller: \'" + ctrl +"',\n" +
-    "abstract: " + route.abstract + ",\n" +
-    "})";
+  var configRoute = 
+    "\t.state(\'"+ route.state +"\', {\n" +
+    "\t\turl: \'" + route.url + "',\n" +
+    "\t\ttemplateUrl: \'templates/" + view + ".html\'\n,"+
+    "\t\tcontroller: \'" + ctrl +".js\',\n" +
+    "\t\tabstract: " + route.abstract + ",\n" +
+    "\t})";
   var ctrlFile = self.readFileAsString(path.join(__dirname, '../templates/scripts/ctrl.js'))
   ctrlFile = ctrlFile.replace(new RegExp("{{APP_NAME}}", 'g'), self.appName);
   ctrlFile = ctrlFile.replace(new RegExp("{{CTRL_NAME}}", 'g'), ctrl);
@@ -69,6 +69,7 @@ var generateConfigRoute = function(self, configRoutes, route) {
   self.write(ctrlFilePath, ctrlFile);
   self.write(path.join(self.viewPath, view+'.html'), '');
   self.scriptsFile.push(ctrlFilePath);
+  return configRoute;
 }
 
 module.exports = {
@@ -83,6 +84,7 @@ module.exports = {
         self.routes = [];
         showRouteStatePrompt(self, done);
       } else {
+
         done();
       }
     }.bind(self));
@@ -96,13 +98,14 @@ module.exports = {
     }
     for (var i = routes.length - 1; i >= 0; i--) {
       console.log('Installing route:' + routes[i].state);
-      generateConfigRoute(self, configRoutes, routes[i]);
+      configRoutes = configRoutes + generateConfigRoute(self, routes[i]);
     };
     var file = self.readFileAsString(path.join(__dirname, '../templates/scripts/config.js'))
     file = file.replace(new RegExp("{{APP_NAME}}", 'g'), self.appName);
     file = file.replace(new RegExp("{{ROUTES}}", 'g'), configRoutes);
-    self.write(path.join(self.appPath, 'config.js'), file);
-    self.scriptsFile.push('config.js');
+    var filePath = path.join(self.jsPath, 'config.js');
+    self.write(filePath, file);
+    self.scriptsFile.push(filePath);
     done();
   }
 };
